======
GEOmap
======

.. figure:: icons/geomap.png

Displays geographic distribution of data. 

Signals
-------

**Inputs**:

-  **Data**

Data set.

**Outputs**:

-  **Corpus**

Corpus instance.

Description
-----------

No description yet for this widget.

Example
-------

No example yet for this widget.
